@@ -1,9 +1,10 @@
 from flask_log_request_id import current_request_id
 
-from .services import ServiceEnum
 
-
-def adscale_log(service: ServiceEnum, msg: str):
+def adscale_log(
+    service: str,  # should be ValueOf ServiceEnum
+    msg: str
+    ):
     request_id = None
     try:
         request_id = current_request_id()
